from setuptools import setup, find_packages
import os

# Read the contents of your README file
this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='tamilpp', # The name users will type: pip install tamilpp
    version='1.0.4',
    description='A Tamil programming language compiler built on Python.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Shriman M', # Your name
    author_email='msm14800@gmail.com', # Update this!
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'tamilpp=tamilpp.cli:run',
            'tamilppc=tamilpp.cli:compile_file',
        ],
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
    ],
    python_requires='>=3.6',
)